==> jc-1.4.0.tar.gz: java/util/ConcurrentModificationException.h <==
// public class java.util.ConcurrentModificationException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 52f944b5de1e20c4 java_util_ConcurrentModificationException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_java_util_ConcurrentModificationException_H_
#define _JC_java_util_ConcurrentModificationException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_util_ConcurrentModificationException$sub_refs	_jc_java_util_ConcurrentModificationException$sub_refs;
typedef struct _jc_java_util_ConcurrentModificationException$sub_nonrefs	_jc_java_util_ConcurrentModificationException$sub_nonrefs;
typedef struct _jc_java_util_ConcurrentModificationException$refs	_jc_java_util_ConcurrentModificationException$refs;
typedef struct _jc_java_util_ConcurrentModificationException$nonrefs	_jc_java_util_ConcurrentModificationException$nonrefs;
typedef struct _jc_java_util_ConcurrentModificationException$object	_jc_java_util_ConcurrentModificationException$object;

typedef struct _jc_java_util_ConcurrentModificationException$fields_struct	_jc_java_util_ConcurrentModificationException$fields_struct;
typedef const struct _jc_java_util_ConcurrentModificationException$vmethods	_jc_java_util_ConcurrentModificationException$vmethods;
typedef const struct _jc_java_util_ConcurrentModificationException$vtable	_jc_java_util_ConcurrentModificationException$vtable;
typedef const struct _jc_java_util_ConcurrentModificationException$vtype	_jc_java_util_ConcurrentModificationException$vtype;

// Class fields structure
struct _jc_java_util_ConcurrentModificationException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_ConcurrentModificationException$fields_struct _jc_java_util_ConcurrentModificationException$class_fields;

// Constructors
extern void _jc_java_util_ConcurrentModificationException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_ConcurrentModificationException$object *);
extern void _jc_java_util_ConcurrentModificationException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_util_ConcurrentModificationException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_util_ConcurrentModificationException$vmethods {
};

// Vtable
struct _jc_java_util_ConcurrentModificationException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_util_ConcurrentModificationException$vmethods	java_util_ConcurrentModificationException;
};

// Vtype
struct _jc_java_util_ConcurrentModificationException$vtype {
	_jc_type			type;
	_jc_java_util_ConcurrentModificationException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_ConcurrentModificationException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_ConcurrentModificationException$refs {
    _jc_java_util_ConcurrentModificationException$sub_refs	java_util_ConcurrentModificationException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_ConcurrentModificationException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_ConcurrentModificationException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_util_ConcurrentModificationException$sub_nonrefs	java_util_ConcurrentModificationException;
};

// Object instance structure
struct _jc_java_util_ConcurrentModificationException$object {
	_jc_java_util_ConcurrentModificationException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_ConcurrentModificationException$vtype	*vtype;
	_jc_java_util_ConcurrentModificationException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_ConcurrentModificationException$vtype _jc_java_util_ConcurrentModificationException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_ConcurrentModificationException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_ConcurrentModificationException$class_object;

#endif	/* _JC_java_util_ConcurrentModificationException_H_ */

==> jc-1.4.6.tar.gz: java/util/ConcurrentModificationException.h <==
// public class java.util.ConcurrentModificationException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 52f944b5de1e20c4 java_util_ConcurrentModificationException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_java_util_ConcurrentModificationException_H_
#define _JC_java_util_ConcurrentModificationException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_util_ConcurrentModificationException$sub_refs	_jc_java_util_ConcurrentModificationException$sub_refs;
typedef struct _jc_java_util_ConcurrentModificationException$sub_nonrefs	_jc_java_util_ConcurrentModificationException$sub_nonrefs;
typedef struct _jc_java_util_ConcurrentModificationException$refs	_jc_java_util_ConcurrentModificationException$refs;
typedef struct _jc_java_util_ConcurrentModificationException$nonrefs	_jc_java_util_ConcurrentModificationException$nonrefs;
typedef struct _jc_java_util_ConcurrentModificationException$object	_jc_java_util_ConcurrentModificationException$object;

typedef struct _jc_java_util_ConcurrentModificationException$fields_struct	_jc_java_util_ConcurrentModificationException$fields_struct;
typedef const struct _jc_java_util_ConcurrentModificationException$vmethods	_jc_java_util_ConcurrentModificationException$vmethods;
typedef const struct _jc_java_util_ConcurrentModificationException$vtable	_jc_java_util_ConcurrentModificationException$vtable;
typedef const struct _jc_java_util_ConcurrentModificationException$vtype	_jc_java_util_ConcurrentModificationException$vtype;

// Class fields structure
struct _jc_java_util_ConcurrentModificationException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_ConcurrentModificationException$fields_struct _jc_java_util_ConcurrentModificationException$class_fields;

// Constructors
extern void _jc_java_util_ConcurrentModificationException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_ConcurrentModificationException$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_ConcurrentModificationException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_util_ConcurrentModificationException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_util_ConcurrentModificationException$vmethods {
};

// Vtable
struct _jc_java_util_ConcurrentModificationException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_util_ConcurrentModificationException$vmethods	java_util_ConcurrentModificationException;
};

// Vtype
struct _jc_java_util_ConcurrentModificationException$vtype {
	_jc_type			type;
	_jc_java_util_ConcurrentModificationException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_ConcurrentModificationException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_ConcurrentModificationException$refs {
    _jc_java_util_ConcurrentModificationException$sub_refs	java_util_ConcurrentModificationException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_ConcurrentModificationException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_ConcurrentModificationException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_util_ConcurrentModificationException$sub_nonrefs	java_util_ConcurrentModificationException;
};

// Object instance structure
struct _jc_java_util_ConcurrentModificationException$object {
	_jc_java_util_ConcurrentModificationException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_ConcurrentModificationException$vtype	*vtype;
	_jc_java_util_ConcurrentModificationException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_ConcurrentModificationException$vtype _jc_java_util_ConcurrentModificationException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_ConcurrentModificationException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_ConcurrentModificationException$class_object;

#endif	/* _JC_java_util_ConcurrentModificationException_H_ */
